bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.move_plates
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.move_plates